pub fn batch_preprocess(a: &[G1Affine], b: &mut [G1PTEAffine])Expand description
convert affine Weierstrass to affine extended Twisted Edwards in batch
pub fn batch_preprocess(a: &[G1Affine], b: &mut [G1PTEAffine])convert affine Weierstrass to affine extended Twisted Edwards in batch