pub struct PreprocessedAffine<P: TECurveConfig> {
pub x: P::BaseField,
pub y: P::BaseField,
pub kt: P::BaseField,
}Expand description
Affine coordinates for a point on a twisted Edwards curve, over the
base field P::BaseField.
Includes the coordinate 2D*x*y.
Fields
x: P::BaseFieldX coordinate of the point represented as a field element
y: P::BaseFieldY coordinate of the point represented as a field element
kt: P::BaseFieldPrecomputed product kXY, k=2D - formulas for A=-1
Implementations